#============================================================
# GnuPlot script : STD.GNU
#============================================================
# Parameter 0 : input data file
# Parameter 1 : graph title
# Parameter 2 : min X:max x
# Parameter 3 : min y:max y
# Parameter 4 : Size X, Size y
# Parameter 5 : output file (PNG format)
#============================================================

# -------------------------------------
# Setting
# -------------------------------------
#palette by Namio MATUDA
lmax = 7800; lmin = 3800
k=lmax-lmin
set cbrange [lmin:lmax]
r(x)=x<4400?-(x-4400)/(4400-3800):x<5100?0:x<5800?(x-5100)/(5800-5100):x<=7800?1:0
g(x)=x<4400?0:x<4900?(x-4400)/(4900-4400):x<5800?1:x<6450?-(x-6450)/(6450-5800):0
b(x)=x<4900?1:x<5100?-(x-5100)/(5100-4900):0
f(x)=x<4200?0.1+0.7*(x-3800)/(4200-3800):x<7200?1:0.2+0.7*(7800-x)/(7800-7200)
set palette functions f(k*gray+lmin)*r(k*gray+lmin),g(k*gray+lmin),f(k*gray+lmin)*b(k*gray+lmin)
set encoding utf8 ## required for Å symbol
set xlabel 'Wavelength (Å)'  ## lambda char = {/Symbol l}
set ylabel "Relative intensity"
set title '$1' offset 0,-0.5
set tmargin 2  ## top margin
set xrange [$2]
set yrange [$3]
set yrange [0<*:]  ## no negative y value (required for color boxes)
set grid ytics xtics mxtics  ## grid : comment this line to disable it, or choose in  ytics xtics mytics mxtics
set mxtics  ## minor x tics
set mytics  ## minor y tics 
set style fill transparent solid 0.5 noborder  ## colored boxes style ; 0.6=60% opacity
set key off ## disable keys (legends)
unset colorbox ## disable color scale

set terminal push

# -------------------------------------
# Plot on the computer screen
# -------------------------------------
set terminal windows "Arial" 9

## /!\ only 1 enabled plot command /!\

## classic black line chart : 
#plot "$0" with line linecolor rgb 'black'

## color-filled chart with black line :
plot "$0" using 1:2:1 with boxes linecolor palette , "$0" with line linecolor rgb 'black'

## colored line chart :
#plot "$0" using 1:2:1 with line linecolor palette z

# -------------------------------------
# Plot on a PNG file
# -------------------------------------
## terminal pngcairo instead of png is needed for transparency, unicod, ...
set terminal pngcairo enhanced font "Verdana,9" size $4
set output '$5'
replot

# -------------------------------------
# Finalize
# -------------------------------------
set output
set terminal pop
reset