#============================================================
# GnuPlot script  : STD2Y.GNU
#============================================================
# Parameter 0 : input data file
# Parameter 1 : graph title
# Parameter 2 : min X:max X
# Parameter 3 : min y1:max y1
# Parameter 4 : min Y2:max y2 
# Parameter 5 : Size X, Size y 
# Parameter 6 : output file (PNG format)
#============================================================

# -----------------------------------------
# Setting
# -----------------------------------------
#palette by Namio MATUDA
lmax = 7800; lmin = 3800
k=lmax-lmin
set cbrange [lmin:lmax]
r(x)=x<4400?-(x-4400)/(4400-3800):x<5100?0:x<5800?(x-5100)/(5800-5100):x<=7800?1:0
g(x)=x<4400?0:x<4900?(x-4400)/(4900-4400):x<5800?1:x<6450?-(x-6450)/(6450-5800):0
b(x)=x<4900?1:x<5100?-(x-5100)/(5100-4900):0
f(x)=x<4200?0.2+0.7*(x-3800)/(4200-3800):x<7200?1:0.2+0.7*(7800-x)/(7800-7200)
set palette functions f(k*gray+lmin)*r(k*gray+lmin),g(k*gray+lmin),f(k*gray+lmin)*b(k*gray+lmin)
set encoding utf8
set xlabel "Wavelength (Å)"  ## lambda char = {/Symbol l}
set ylabel "Relative intensity"
set tmargin 2
set title '$1' offset 0,-0.5
set xrange [$2]
set yrange [$3]
set yrange [0<*:]  ## no negative y value (required for color boxes)
set y2range [$4]
set y2range [0<*:]  ## no negative y2 value (required for color boxes)
set y2tics border
set ytics nomirror
set mxtics  ## minor x tics
set grid ytics xtics mxtics y2tics x2tics mx2tics  ## grid : comment this line to disable it, or choose in  ytics xtics mytics mxtics y2tics x2tics my2tics mx2tics
set key off ## disable keys (legends)
set style fill transparent solid 0.4 noborder  ## colored boxes style ; 0.4=40% opacity
unset colorbox ## disable color scale
set terminal push

# ----------------------------------------
# Plot on the computer screen
# ----------------------------------------
set terminal windows "Arial" 9

## /!\ only 1 enabled plot/replot commands block /!\

## color-filled + black/grey lines
plot "$0" using 1:2:1 with boxes linecolor palette notitle , "$0" using 1:2:1 with boxes linecolor palette notitle axes x1y2 
replot "$0" with lines lc rgb 'black', "$0" axes x1y2 with lines lc rgb 'gray70'

#classic black/grey lines
#plot "$0" with lines lc rgb 'black', "$0" axes x1y2 with lines lc rgb 'gray70'

# ----------------------------------------
# Plot on a PNG file
# ----------------------------------------
set terminal pngcairo enhanced font "Verdana,9" size $5
set output '$6'
replot

# ----------------------------------------
# Finalize
# ----------------------------------------
set output
set terminal pop
reset

